
// General
#define NET_NEWPLAYER 100
#define NET_STARTGAME 2
#define NET_ENDGAME 3
#define NET_PLAYERNAME 4

// Build and Place
#define NET_BPLAYER_MOVE 10
#define NET_BLOCKGEN 11
#define NET_TURN 12
#define NET_PUTBLOCK 13
#define NET_ADDHOUSE 14
#define NET_BUTTON2 15
#define NET_CLEAN 16
#define NET_PUTCANNON 17
#define NET_PLACE_PLAYER_MOVE 18

// Battle
#define NET_BATTLE_MOVE 20
#define NET_SHOOT 21
#define NET_NEWTANK 22
#define NET_TANKMOVE 23
#define NET_TANKSHOOT 24

// Castle Selection
#define NET_OTHER_SELECTION 30
#define NET_SELECTION_FINISHED 31
#define NET_CASTLE_RANDOMIZE 40

// Sync Commands
#define NET_SYNC_WALL 50
#define NET_SYNC_GARBAGE 51
#define NET_SYNC_HOUSE 52

// Port number
#define MAKE_NUM(A, B, C, D)	(((A+B)<<8)|(C+D)) /* Convert four letters into a number */
#define NET_PORT	MAKE_NUM('c','a','c','o')

/* The protocol between the NET client and server */
#define NET_HELLO		0	/* 0+Port+len+name */
#define NET_HELLO_NLEN		1
#define NET_HELLO_PLAYERNUM     2
#define NET_HELLO_CONQUER       3
#define NET_HELLO_NAME		4
